<?php
class ModelPaymentZGlobalPay extends Model {

	public function install() {
		$this->db->query("
			CREATE TABLE IF NOT EXISTS `" . DB_PREFIX . "zglobalpay_tranxlog` (
			`id` BIGINT NOT NULL AUTO_INCREMENT,
			`order_id` BIGINT NOT NULL,
			`cust_name` VARCHAR(50) NOT NULL,
			`email` VARCHAR(100) NOT NULL,			
			`tranx_id` VARCHAR(50) NOT NULL,
			`tranx_date` DATETIME,
			`amount` FLOAT(11,2) NOT NULL,			
			`currency` CHAR(3) NOT NULL DEFAULT 'NGN',
			`channel` VARCHAR(20),
			`status` ENUM('Pending','Failed','Successful') NOT NULL DEFAULT 'Pending',
			`capture_status` TINYINT(1),
			`response` VARCHAR(255),			
			`tranx_meta` TEXT,
			`last_date_modified` TIMESTAMP,
			`last_ip_modified` VARCHAR(100) DEFAULT NULL,
			PRIMARY KEY (`id`,`tranx_id`),
 			UNIQUE KEY `tranx_id` (`tranx_id`),
			INDEX(order_id,email,status))
			ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Zenith GlobalPay Transaction Log';");
			
			/*
			`response` VARCHAR(255) NOT NULL DEFAULT '', //Response & Description				
			`cust_meta` MEDIUMTEXT NOT NULL, //JSON - CustomerName, Email
			`tranx_meta` TEXT NOT NULL, //JSON - StoreName, BuyerIP, TranxMemo
			*/
	}

	public function checkPrevTables(){
		// Check & alter/convert former versions tablenames and fields to current
		
		// Check if table exists
		$count = $this->db->query("
		SELECT COUNT(*)
		FROM information_schema.tables 
		WHERE table_schema = `" . DB_PREFIX . "` 
		AND table_name = 'transactions'");
		
		//If exists
		if ($count > 0) { echo 'Table Exists';
		
		$this->db->query("
		RENAME TABLE `" . DB_PREFIX . "transactions` TO zglobalpay_tranxlog,
		
		ALTER IGNORE TABLE `" . DB_PREFIX . "transactions`
		
		CHANGE `cart_id` `order_id` BIGINT NOT NULL,
		CHANGE `completed_date` `last_date_modified` TIMESTAMP,
		CHANGE `ip` `last_ip_modified` TIMESTAMP,
		CHANGE `tranx_memo` `tranx_meta` TEXT AFTER `response`,
		
		MODIFY `id` BIGINT NOT NULL AUTO_INCREMENT,
		MODIFY `cust_name` VARCHAR(50) NOT NULL,
		MODIFY `tranx_id` VARCHAR(50) NOT NULL,
		MODIFY `response` VARCHAR(255),
		
		ADD `capture_status` TINYINT(1) AFTER `status`,
		
		DROP COLUMN `comments`");
		 }
	}
			
	public function createOrderTable(){
		$this->db->query( "CREATE TABLE IF NOT EXISTS " . DB_PREFIX . "zglobalpay_order (
				sp_order_id INT(11) UNSIGNED AUTO_INCREMENT,
				order_id INT(11) UNSIGNED,
				charge_ref VARCHAR(255),
				date_added DATETIME,
				date_modified TIMESTAMP,
				capture_status TINYINT(1),
				description VARCHAR(255),
				total INT(11),
				currency_code VARCHAR(3),
				PRIMARY KEY(sp_order_id),
				INDEX(charge_ref,order_id))
				ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin");
	}

	public function deleteOrderTable(){
		$this->db->query( "DROP TABLE IF EXISTS " . DB_PREFIX . "zglobalpay_order" );
	}
	
	public function getOrder($order_id) {
		$qry = $this->db->query("SELECT * FROM `" . DB_PREFIX . "zglobalpay_order` WHERE `order_id` = '" . (int)$order_id . "' LIMIT 1");

		if ($qry->num_rows) {
			$order = $qry->row;
			return $order;
		} else {
			return false;
		}
	}
	
	public function addOrderHistory($order_id, $data, $store_id = 0) {
		$json = array();

		$this->load->model('setting/store');

		$store_info = $this->model_setting_store->getStore($store_id);

		if ($store_info) {
			$url = $store_info['ssl'];
		} else {
			$url = HTTPS_CATALOG;
		}

		if (isset($this->session->data['cookie'])) {
			$curl = curl_init();

			// Set SSL if required
			if (substr($url, 0, 5) == 'https') {
				curl_setopt($curl, CURLOPT_PORT, 443);
			}

			curl_setopt($curl, CURLOPT_HEADER, false);
			curl_setopt($curl, CURLINFO_HEADER_OUT, true);
			curl_setopt($curl, CURLOPT_USERAGENT, $this->request->server['HTTP_USER_AGENT']);
			curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl, CURLOPT_FORBID_REUSE, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_URL, $url . 'index.php?route=api/order/history&order_id=' . $order_id);
			curl_setopt($curl, CURLOPT_POST, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($data));
			curl_setopt($curl, CURLOPT_COOKIE, session_name() . '=' . $this->session->data['cookie'] . ';');

			$json = curl_exec($curl);

			curl_close($curl);
		}

		return $json;
	}
}